from palettable.tableau import Tableau_10

almost_black = '#262626'
light_gray = '#E5E5E5'
light_grey = light_gray
steel_blue = '#3F5D7D'
# I saw the national park road signs and loved the color, so I found it. Here
# is the source if you want (PDF):
# http://www.pc.gc.ca/eng/docs/bib-lib/~/media/docs/bib-lib/pdfs/Exterior_Signage.ashx
# Search for Parks Canada Heritage Green, and you will see that it is the
# color on the signs, and that they give the pantone shade. I found a tool
# online that can convert that to the hex color.
parks_canada_heritage_green = '#284734'
pchg = parks_canada_heritage_green  # alias

color_cycle = Tableau_10.hex_colors
